package com.mindoo.ftp.connection;

import org.apache.ftpserver.DataConnectionConfiguration;
import org.apache.ftpserver.DataConnectionConfigurationFactory;
import org.apache.ftpserver.ssl.SslConfiguration;

public class DataConnectionConfigurationWrapper implements DataConnectionConfiguration {
	private DataConnectionConfiguration dataConnectionConfig = new DataConnectionConfigurationFactory().createDataConnectionConfiguration();

	public DataConnectionConfigurationWrapper() {
	}

	/**
	 * Get the maximum idle time in seconds.
	 */
	public int getIdleTime() {
		return dataConnectionConfig.getIdleTime();
	}

	/**
	 * Is PORT enabled?
	 */
	public boolean isActiveEnabled() {
		return dataConnectionConfig.isActiveEnabled();
	}

	/**
	 * Check the PORT IP?
	 */
	public boolean isActiveIpCheck() {
		return dataConnectionConfig.isActiveIpCheck();
	}

	/**
	 * Get the local address for active mode data transfer.
	 */
	public String getActiveLocalAddress() {
		return dataConnectionConfig.getActiveLocalAddress();
	}

	/**
	 * Get the active local port number.
	 */
	public int getActiveLocalPort() {
		return dataConnectionConfig.getActiveLocalPort();
	}

	/**
	 * Get passive host.
	 */
	public String getPassiveAddress() {
		return dataConnectionConfig.getPassiveAddress();
	}

	/**
	 * Get external passive host.
	 */
	public String getPassiveExernalAddress()  {
		return dataConnectionConfig.getPassiveExernalAddress();
	}

	public boolean isPassiveIpCheck() {
		return dataConnectionConfig.isPassiveIpCheck();
	}

	/**
	 * Get passive data port. Data port number zero (0) means that any available
	 * port will be used.
	 */
	public synchronized int requestPassivePort() {
		return dataConnectionConfig.requestPassivePort();
	}

	/**
	 * Retrive the passive ports configured for this data connection
	 * 
	 * @return The String of passive ports
	 */
	public String getPassivePorts() {
		return dataConnectionConfig.getPassivePorts();
	}

	/**
	 * Release data port
	 */
	public synchronized void releasePassivePort(final int port) {
		dataConnectionConfig.releasePassivePort(port);
	}

	/**
	 * Get SSL component.
	 */
	public SslConfiguration getSslConfiguration() {
		return dataConnectionConfig.getSslConfiguration();
	}

	/**
	 * @see org.apache.ftpserver.DataConnectionConfiguration#isImplicitSsl()
	 */
	public boolean isImplicitSsl() {
		return dataConnectionConfig.isImplicitSsl();
	}
}
